# Maxim Python Library

Python SDK to integrate Maxim AI. More info at [Maxim Site](https://getmaxim.ai). Maxim is an enterprise grade evaluation and monitoring platform for your GenAI applications.

## Version changelog

### v1.2.1

* Fixed MaximLangchainTracer error logging flow.

### v1.2.0

* Adds langchain support
* Adds local parsers to validate payloads on client side

### v1.1.0

* Minor bug fixes around log writer cleanup

### v1.0.0

* Public release
